# SAP LeanIX Applications Terms and Conditions (Microsoft Teams)
### On this page
  * [Provision of the Application](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#provision-of-the-application)
  * [LeanIX Terms](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#leanix-terms)
  * [Data](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#data)
  * [Disclaimer](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#disclaimer)
  * [Limitations of Liability](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#limitations-of-liability)
  * [Miscellaneous](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams#miscellaneous)


This document ("SAP LeanIX Applications Terms and Conditions") sets forth the terms and conditions for access and use of the LeanIX Integration for Microsoft Teams ("LeanIX Notifications”) and associated documentation (the "Application"), and it is a legal agreement between your company (“you”, “your”, “your company” or “Customer”) and the LeanIX entity with which your company entered into a contract with (“LeanIX”). Please be aware that by agreeing to these Application Terms, you represent and warrant that you have the authority to enter on such entity’s behalf into - and to legally bind it to - the terms below.
